<?php
/*
 * Plugin Name: SideMenu Premium
 * Version: 1.1.5
 * Plugin URI: https://webd.uk/product/sidemenu-upgrade/
 * Description: Adds even more options to the SideMenu
 * Author: Webd Ltd
 * Author URI: https://webd.uk
 */



if (!defined('ABSPATH')) {
    exit('This isn\'t the page you\'re looking for. Move along, move along.');
}



if (!class_exists('sidemenu_premium_class')) {

	class sidemenu_premium_class {

        public static $version = '1.1.5';

		function __construct() {

            add_action('customize_register', array($this, 'sidemenu_customize_register'), 999);
            add_action('wp_head' , array($this, 'sidemenu_header_output'), 11);

            if (is_admin()) {

                add_action('load-post.php', array($this, 'sidemenu_theme_options_metabox_setup'));
                add_action('load-post-new.php', array($this, 'sidemenu_theme_options_metabox_setup'));
                add_filter('pre_set_site_transient_update_plugins', 'sidemenuPremium::check_plugin_update');
                add_filter('plugins_api', 'sidemenuPremium::get_plugin_information', 10, 3);
                add_filter('after_plugin_row_' . plugin_basename(__FILE__), 'sidemenuPremium::activate_purchase_js', 10, 3);
                add_action('wp_ajax_sidemenu_activate_purchase', 'sidemenuPremium::activate_purchase');
                add_action('admin_notices', 'sidemenuPremium::upgrade_notice');
                add_filter('upgrader_pre_download', 'sidemenuPremium::upgrader_pre_download', 10, 3);
                add_filter('plugin_action_links_' . plugin_basename(__FILE__), array($this, 'sidemenu_add_plugin_action_links'));
                add_filter('plugin_row_meta', 'sidemenuPremium::plugin_row_meta', 10, 4);
                add_action('customize_controls_enqueue_scripts', 'sidemenuCommon::enqueue_customize_controls_js');

            } else {

                add_action('customize_preview_init', array($this, 'sidemenu_enqueue_customize_preview_js'));
                add_action('wp_enqueue_scripts', array($this, 'sidemenu_enqueue_scripts'));

            }

            add_action('customize_register', 'webd_customize_register');

		}

		function sidemenu_add_plugin_action_links($links) {

			$settings_links = sidemenuCommon::plugin_action_links(add_query_arg('autofocus[section]', 'sidemenu', admin_url('customize.php')), true);

			return array_merge($settings_links, $links);

		}

        function sidemenu_customize_register($wp_customize) {

            if (!class_exists('reset_customizer_class')) {

                $wp_customize->add_section('reset_customizer', array(
                    'title'     => __('Reset Customizer', 'reset-customizer'),
                    'description'  => __('Reset Customizer allows you to reset the options within each section of the customizer to their defaults without affecting other settings. You can also backup, delete and restore entire sets of customizer theme mods.', 'sidemenu'),
                    'priority'     => 0
                ));

                sidemenuCommon::add_hidden_control($wp_customize, 'install_reset_customizer', 'reset_customizer', '', sprintf(wp_kses(__('<a href="%s" class="button-primary">Install Reset Customizer plugin</a>.', 'sidemenu'), array('a' => array('href' => array(), 'class' => array()))), esc_url(wp_nonce_url(add_query_arg(array('action' => 'install-plugin', 'plugin' => 'reset-customizer'), self_admin_url('update.php')), 'install-plugin_reset-customizer'))));

            }



            $upgrade_link = '<a href="' . sidemenuCommon::upgrade_link() . '" title="' . __('Upgrade to SideMenu Premium', 'sidemenu') . '">' . __('Upgrade to SideMenu Premium', 'sidemenu') . '</a>';
            $upgrade_nag = $upgrade_link . __(' to activate this option.', 'sidemenu');



            if (file_exists(ABSPATH . WPINC . '/css/dashicons.css')) {

                $dashicons_css = explode("\n", implode('', file(ABSPATH . WPINC . '/css/dashicons.css')));
                $dashicons = array();

                foreach ($dashicons_css as $css_entry) {

                    if (strlen($css_entry) > 10 && substr($css_entry, 0, 11) === '.dashicons-') {

                        $dashicon_class = sanitize_key(preg_replace(array('/^.dashicons-/', '/:before {$/'), '', $css_entry));
                        $dashicons[$dashicon_class] = __(ucwords(str_replace('-', ' ', $dashicon_class)), 'sidemenu');

                    }

                }

                asort($dashicons);

                $control_label = __('Dashicon', 'sidemenu');
                $control_description = sprintf(wp_kses(__('Choose your own <a href="%s">dashicon</a> for the button that opens the SideMenu.', 'sidemenu'), array('a' => array('href' => array()))), esc_url('https://developer.wordpress.org/resource/dashicons/'));

                if (sidemenuPremium::request_permission()) {

                    $wp_customize->add_setting('sidemenu_dashicon', array(
                        'default'       => 'menu-alt',
                        'type'          => 'theme_mod',
                        'transport'     => 'refresh',
                        'sanitize_callback' => 'sidemenuCommon::sanitize_options'
                    ));
                    $wp_customize->add_control('sidemenu_dashicon', array(
                        'label'         => $control_label,
                        'description'   => $control_description,
                        'section'       => 'sidemenu',
                        'settings'      => 'sidemenu_dashicon',
                        'type'          => 'select',
                        'choices'       => $dashicons
                    ));

                } else {

                    sidemenuCommon::add_hidden_control($wp_customize, 'sidemenu_dashicon', 'sidemenu', $label = $control_label, $control_description . ' ' . $upgrade_nag);

                }

            }

            $control_label = __('Dashicon Size', 'sidemenu');
            $control_description = __('Set the size of the dashicon.', 'sidemenu');

            if (sidemenuPremium::request_permission()) {

                $wp_customize->add_setting('sidemenu_dashicon_size', array(
                    'default'       => '20',
                    'type'          => 'theme_mod',
                    'transport'     => 'postMessage',
                    'sanitize_callback' => 'absint'
                ));
                $wp_customize->add_control('sidemenu_dashicon_size', array(
                    'label'         => $control_label,
                    'description'   => $control_description,
                    'section'       => 'sidemenu',
                    'settings'      => 'sidemenu_dashicon_size',
                    'type'          => 'range',
                    'input_attrs' => array(
                        'min'   => 10,
                        'max'   => 100,
                        'step'  => 1
                    )
                ));

            } else {

                sidemenuCommon::add_hidden_control($wp_customize, 'sidemenu_dashicon_size', 'sidemenu', $label = $control_label, $control_description . ' ' . $upgrade_nag);

            }

            $control_label = __('Auto Open', 'sidemenu');
            $control_description = __('Set which pages the SideMenu should open on automatically.', 'sidemenu');

if (sidemenuPremium::request_permission() == true) {

            $auto_open_locations = array(
                'all' => __('Everywhere', 'sidemenu'),
                'front_page' => __('Front Page', 'sidemenu'),
                'home' => __('Main Blog Page', 'sidemenu'),
                'single' => __('Single Posts', 'sidemenu'),
                'archive' => __('Archive Pages', 'sidemenu')
            );

            foreach(get_post_types(array('public' => 'true')) as $post_type) {

                $post_type_object = get_post_type_object($post_type);
                $auto_open_locations['post_type/' . $post_type] = __('Post Type: ', 'sidemenu') . $post_type_object->label;

                foreach (get_object_taxonomies($post_type, 'objects') as $taxonomy) {

                    $auto_open_locations['taxonomy/' . $post_type . '/' . $taxonomy->name] = $post_type_object->label . __(' Taxonomy: ', 'sidemenu') . $taxonomy->label;

                }

            }

            $wp_customize->add_setting('sidemenu_auto_open', array(
                'default'       => array(
				    'author',
				    'post-date',
				    'comments',
				    'sticky'
				),
                'transport'     => 'refresh',
                'sanitize_callback' => 'sidemenuCommon::sanitize_multiple_options'
            ));
            $wp_customize->add_control(new webd_Customize_Control_Checkbox_Multiple($wp_customize, 'sidemenu_auto_open', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'sidemenu',
                'settings'      => 'sidemenu_auto_open',
                'choices'       => $auto_open_locations
            )));

} else {

            sidemenuCommon::add_hidden_control($wp_customize, 'sidemenu_auto_open', 'sidemenu', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Auto-Open Delay', 'sidemenu');
            $control_description = __('Set the delay before the SideMenu opens on posts and pages set to auto-open the SideMenu.', 'sidemenu');

            if (sidemenuPremium::request_permission()) {

                $wp_customize->add_setting('sidemenu_auto_open_delay', array(
                    'default'       => '0',
                    'type'          => 'theme_mod',
                    'transport'     => 'refresh',
                    'sanitize_callback' => 'absint'
                ));
                $wp_customize->add_control('sidemenu_auto_open_delay', array(
                    'label'         => $control_label,
                    'description'   => $control_description,
                    'section'       => 'sidemenu',
                    'settings'      => 'sidemenu_auto_open_delay',
                    'type'          => 'range',
                    'input_attrs' => array(
                        'min'   => 0,
                        'max'   => 5000,
                        'step'  => 100
                    )
                ));

            } else {

                sidemenuCommon::add_hidden_control($wp_customize, 'sidemenu_auto_open_delay', 'sidemenu', $label = $control_label, $control_description . ' ' . $upgrade_nag);

            }

            $control_label = __('Overlay Color', 'sidemenu');
            $control_description = __('Set the background color of the overlay that dims the main website.', 'sidemenu');

            if (sidemenuPremium::request_permission()) {

                $wp_customize->add_setting('sidemenu_overlay_color', array(
                    'default'       => '#000000',
                    'type'          => 'theme_mod',
                    'transport'     => 'postMessage',
                    'sanitize_callback' => 'sanitize_hex_color'
                ));
                $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'sidemenu_overlay_color', array(
                    'label'         => $control_label,
                    'description'   => $control_description,
                    'section'       => 'sidemenu',
                	'settings'      => 'sidemenu_overlay_color'
                )));

            } else {

                sidemenuCommon::add_hidden_control($wp_customize, 'sidemenu_overlay_color', 'sidemenu', $label = $control_label, $control_description . ' ' . $upgrade_nag);

            }

            $control_label = __('Overlay Opacity', 'sidemenu');
            $control_description = __('Set the opacity of the overlay that dims the main website.', 'sidemenu');

            if (sidemenuPremium::request_permission()) {

                $wp_customize->add_setting('sidemenu_overlay_opacity', array(
                    'default'       => '7',
                    'type'          => 'theme_mod',
                    'transport'     => 'postMessage',
                    'sanitize_callback' => 'absint'
                ));
                $wp_customize->add_control('sidemenu_overlay_opacity', array(
                    'label'         => $control_label,
                    'description'   => $control_description,
                    'section'       => 'sidemenu',
                    'settings'      => 'sidemenu_overlay_opacity',
                    'type'          => 'range',
                    'input_attrs' => array(
                        'min'   => 1,
                        'max'   => 11,
                        'step'  => 1
                    )
                ));

            } else {

                sidemenuCommon::add_hidden_control($wp_customize, 'sidemenu_overlay_opacity', 'sidemenu', $label = $control_label, $control_description . ' ' . $upgrade_nag);

            }

            $control_label = __('SideMenu Width', 'sidemenu');
            $control_description = __('Set the width of the SideMenu as a percentage of the display width.', 'sidemenu');

            if (sidemenuPremium::request_permission()) {

                $wp_customize->add_setting('sidemenu_width', array(
                    'default'       => '45',
                    'type'          => 'theme_mod',
                    'transport'     => 'refresh',
                    'sanitize_callback' => 'absint'
                ));
                $wp_customize->add_control('sidemenu_width', array(
                    'label'         => $control_label,
                    'description'   => $control_description,
                    'section'       => 'sidemenu',
                    'settings'      => 'sidemenu_width',
                    'type'          => 'range',
                    'input_attrs' => array(
                        'min'   => 5,
                        'max'   => 100,
                        'step'  => 5
                    )
                ));

            } else {

                sidemenuCommon::add_hidden_control($wp_customize, 'sidemenu_width', 'sidemenu', $label = $control_label, $control_description . ' ' . $upgrade_nag);

            }

            $control_label = __('SideMenu Minimum Width', 'sidemenu');
            $control_description = __('Set the minimum width of the SideMenu.', 'sidemenu');

            if (sidemenuPremium::request_permission()) {

                $wp_customize->add_setting('sidemenu_min_width', array(
                    'default'       => 0,
                    'type'          => 'theme_mod',
                    'transport'     => 'refresh',
                    'sanitize_callback' => 'absint'
                ));
                $wp_customize->add_control('sidemenu_min_width', array(
                    'label'         => $control_label,
                    'description'   => $control_description,
                    'section'       => 'sidemenu',
                    'settings'      => 'sidemenu_min_width',
                    'type'          => 'range',
                    'input_attrs' => array(
                        'min'   => 0,
                        'max'   => 500,
                        'step'  => 50
                    )
                ));

            } else {

                sidemenuCommon::add_hidden_control($wp_customize, 'sidemenu_min_width', 'sidemenu', $label = $control_label, $control_description . ' ' . $upgrade_nag);

            }

            $control_label = __('SideMenu Height', 'sidemenu');
            $control_description = __('Set the height of the SideMenu as a percentage of the display height.', 'sidemenu');

            if (sidemenuPremium::request_permission()) {

                $wp_customize->add_setting('sidemenu_height', array(
                    'default'       => '100',
                    'type'          => 'theme_mod',
                    'transport'     => 'refresh',
                    'sanitize_callback' => 'absint'
                ));
                $wp_customize->add_control('sidemenu_height', array(
                    'label'         => $control_label,
                    'description'   => $control_description,
                    'section'       => 'sidemenu',
                    'settings'      => 'sidemenu_height',
                    'type'          => 'range',
                    'input_attrs' => array(
                        'min'   => 5,
                        'max'   => 100,
                        'step'  => 5
                    )
                ));

            } else {

                sidemenuCommon::add_hidden_control($wp_customize, 'sidemenu_height', 'sidemenu', $label = $control_label, $control_description . ' ' . $upgrade_nag);

            }

            $control_label = __('No Content Animation', 'sidemenu');
            $control_description = __('Prevents the site content from moving when the SideMenu opens.', 'sidemenu');

            if (sidemenuPremium::request_permission()) {

                $wp_customize->add_setting('sidemenu_no_content_animation', array(
                    'default'       => '',
                    'type'          => 'theme_mod',
                    'transport'     => 'refresh',
                    'sanitize_callback' => 'sidemenuCommon::sanitize_boolean'
                ));
                $wp_customize->add_control('sidemenu_no_content_animation', array(
                    'label'         => $control_label,
                    'description'   => $control_description,
                    'section'       => 'sidemenu',
                    'settings'      => 'sidemenu_no_content_animation',
                    'type'          => 'checkbox'
                ));

            } else {

                sidemenuCommon::add_hidden_control($wp_customize, 'sidemenu_no_content_animation', 'sidemenu', $label = $control_label, $control_description . ' ' . $upgrade_nag);

            }

            $control_label = __('Prevent Scroll Close', 'sidemenu');
            $control_description = __('Prevents user scrolling from closing the sidemenu.', 'sidemenu');

            if (sidemenuPremium::request_permission()) {

                $wp_customize->add_setting('sidemenu_prevent_scroll_close', array(
                    'default'       => '',
                    'type'          => 'theme_mod',
                    'transport'     => 'refresh',
                    'sanitize_callback' => 'sidemenuCommon::sanitize_boolean'
                ));
                $wp_customize->add_control('sidemenu_prevent_scroll_close', array(
                    'label'         => $control_label,
                    'description'   => $control_description,
                    'section'       => 'sidemenu',
                    'settings'      => 'sidemenu_prevent_scroll_close',
                    'type'          => 'checkbox'
                ));

            } else {

                sidemenuCommon::add_hidden_control($wp_customize, 'sidemenu_prevent_scroll_close', 'sidemenu', $label = $control_label, $control_description . ' ' . $upgrade_nag);

            }

            $control_label = __('SideMenu Background Color', 'sidemenu');
            $control_description = __('Set the background color of the SideMenu.', 'sidemenu');

            if (sidemenuPremium::request_permission()) {

                $wp_customize->add_setting('sidemenu_background_color', array(
                    'default'       => '#666666',
                    'type'          => 'theme_mod',
                    'transport'     => 'postMessage',
                    'sanitize_callback' => 'sanitize_hex_color'
                ));
                $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'sidemenu_background_color', array(
                    'label'         => $control_label,
                    'description'   => $control_description,
                    'section'       => 'sidemenu',
                	'settings'      => 'sidemenu_background_color'
                )));

            } else {

                sidemenuCommon::add_hidden_control($wp_customize, 'sidemenu_background_color', 'sidemenu', $label = $control_label, $control_description . ' ' . $upgrade_nag);

            }

            $control_label = __('SideMenu Title Alignment', 'sidemenu');
            $control_description = __('Align the titles in the SideMenu to the left, center or right.', 'sidemenu');

            if (sidemenuPremium::request_permission()) {

                $wp_customize->add_setting('sidemenu_title_text_align', array(
                    'default'       => '',
                    'type'          => 'theme_mod',
                    'transport'     => 'postMessage',
                    'sanitize_callback' => 'sidemenuCommon::sanitize_options'
                ));
                $wp_customize->add_control('sidemenu_title_text_align', array(
                    'label'         => $control_label,
                    'description'   => $control_description,
                    'section'       => 'sidemenu',
                    'settings'      => 'sidemenu_title_text_align',
                    'type'          => 'select',
                    'choices'       => array(
                        '' => __('Left', 'sidemenu'),
                        'center' => __('Center', 'sidemenu'),
                        'right' => __('Right', 'sidemenu')
                    )
                ));

            } else {

                sidemenuCommon::add_hidden_control($wp_customize, 'sidemenu_title_text_align', 'sidemenu', $label = $control_label, $control_description . ' ' . $upgrade_nag);

            }

            $control_label = __('SideMenu Title Font Case', 'sidemenu');
            $control_description = __('Change the font case of the titles in the SideMenu.', 'sidemenu');

            if (sidemenuPremium::request_permission()) {

                $wp_customize->add_setting('sidemenu_title_text_transform', array(
                    'default'       => '',
                    'type'          => 'theme_mod',
                    'transport'     => 'postMessage',
                    'sanitize_callback' => 'sidemenuCommon::sanitize_options'
                ));
                $wp_customize->add_control('sidemenu_title_text_transform', array(
                    'label'         => $control_label,
                    'description'   => $control_description,
                    'section'       => 'sidemenu',
                    'settings'      => 'sidemenu_title_text_transform',
                    'type'          => 'select',
                    'choices'       => array(
                        '' => __('None', 'sidemenu'),
                        'capitalize' => __('Capitalise', 'sidemenu'),
                        'uppercase' => __('Uppercase', 'sidemenu'),
                        'lowercase' => __('Lowercase', 'sidemenu')
                    )
                ));

            } else {

                sidemenuCommon::add_hidden_control($wp_customize, 'sidemenu_title_text_transform', 'sidemenu', $label = $control_label, $control_description . ' ' . $upgrade_nag);

            }

            $control_label = __('SideMenu Title Font Size', 'sidemenu');
            $control_description = __('Change the font size of the titles in the SideMenu.', 'sidemenu');

            if (sidemenuPremium::request_permission()) {

                $wp_customize->add_setting('sidemenu_title_font_size', array(
                    'default'       => '15',
                    'type'          => 'theme_mod',
                    'transport'     => 'postMessage',
                    'sanitize_callback' => 'absint'
                ));
                $wp_customize->add_control('sidemenu_title_font_size', array(
                    'label'         => $control_label,
                    'description'   => $control_description,
                    'section'       => 'sidemenu',
                    'settings'      => 'sidemenu_title_font_size',
                    'type'          => 'range',
                    'input_attrs' => array(
                        'min'   => 5,
                        'max'   => 30,
                        'step'  => 1
                    )
                ));

            } else {

                sidemenuCommon::add_hidden_control($wp_customize, 'sidemenu_title_font_size', 'sidemenu', $label = $control_label, $control_description . ' ' . $upgrade_nag);

            }

            $control_label = __('SideMenu Title Font Weight', 'sidemenu');
            $control_description = __('Change the font weight of the titles in the SideMenu.', 'sidemenu');

            if (sidemenuPremium::request_permission()) {

                $wp_customize->add_setting('sidemenu_title_font_weight', array(
                    'default'       => '700',
                    'type'          => 'theme_mod',
                    'transport'     => 'postMessage',
                    'sanitize_callback' => 'absint'
                ));
                $wp_customize->add_control('sidemenu_title_font_weight', array(
                    'label'         => $control_label,
                    'description'   => $control_description,
                    'section'       => 'sidemenu',
                    'settings'      => 'sidemenu_title_font_weight',
                    'type'          => 'range',
                    'input_attrs' => array(
                        'min'   => 100,
                        'max'   => 900,
                        'step'  => 100
                    )
                ));

            } else {

                sidemenuCommon::add_hidden_control($wp_customize, 'sidemenu_title_font_weight', 'sidemenu', $label = $control_label, $control_description . ' ' . $upgrade_nag);

            }

            $control_label = __('SideMenu Title Color', 'sidemenu');
            $control_description = __('Set the color of titles in the SideMenu.', 'sidemenu');

            if (sidemenuPremium::request_permission()) {

                $wp_customize->add_setting('sidemenu_title_color', array(
                    'default'       => '#ffffff',
                    'type'          => 'theme_mod',
                    'transport'     => 'postMessage',
                    'sanitize_callback' => 'sanitize_hex_color'
                ));
                $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'sidemenu_title_color', array(
                    'label'         => $control_label,
                    'description'   => $control_description,
                    'section'       => 'sidemenu',
                	'settings'      => 'sidemenu_title_color'
                )));

            } else {

                sidemenuCommon::add_hidden_control($wp_customize, 'sidemenu_title_color', 'sidemenu', $label = $control_label, $control_description . ' ' . $upgrade_nag);

            }

            $control_label = __('SideMenu Menu Padding', 'sidemenu');
            $control_description = __('Set the padding inbetween menu items in the SideMenu.', 'sidemenu');

            if (sidemenuPremium::request_permission()) {

                $wp_customize->add_setting('sidemenu_menu_padding', array(
                    'default'       => 0,
                    'type'          => 'theme_mod',
                    'transport'     => 'postMessage',
                    'sanitize_callback' => 'absint'
                ));
                $wp_customize->add_control('sidemenu_menu_padding', array(
                    'label'         => $control_label,
                    'description'   => $control_description,
                    'section'       => 'sidemenu',
                    'settings'      => 'sidemenu_menu_padding',
                    'type'          => 'range',
                    'input_attrs' => array(
                        'min'   => 0,
                        'max'   => 10,
                        'step'  => 1
                    )
                ));

            } else {

                sidemenuCommon::add_hidden_control($wp_customize, 'sidemenu_menu_padding', 'sidemenu', $label = $control_label, $control_description . ' ' . $upgrade_nag);

            }

            $control_label = __('SideMenu Text Alignment', 'sidemenu');
            $control_description = __('Align the text in the SideMenu to the left, center or right.', 'sidemenu');

            if (sidemenuPremium::request_permission()) {

                $wp_customize->add_setting('sidemenu_text_align', array(
                    'default'       => '',
                    'type'          => 'theme_mod',
                    'transport'     => 'postMessage',
                    'sanitize_callback' => 'sidemenuCommon::sanitize_options'
                ));
                $wp_customize->add_control('sidemenu_text_align', array(
                    'label'         => $control_label,
                    'description'   => $control_description,
                    'section'       => 'sidemenu',
                    'settings'      => 'sidemenu_text_align',
                    'type'          => 'select',
                    'choices'       => array(
                        '' => __('Left', 'sidemenu'),
                        'center' => __('Center', 'sidemenu'),
                        'right' => __('Right', 'sidemenu')
                    )
                ));

            } else {

                sidemenuCommon::add_hidden_control($wp_customize, 'sidemenu_text_align', 'sidemenu', $label = $control_label, $control_description . ' ' . $upgrade_nag);

            }

            $control_label = __('SideMenu Text Font Case', 'sidemenu');
            $control_description = __('Change the font case of the text in the SideMenu.', 'sidemenu');

            if (sidemenuPremium::request_permission()) {

                $wp_customize->add_setting('sidemenu_text_transform', array(
                    'default'       => '',
                    'type'          => 'theme_mod',
                    'transport'     => 'postMessage',
                    'sanitize_callback' => 'sidemenuCommon::sanitize_options'
                ));
                $wp_customize->add_control('sidemenu_text_transform', array(
                    'label'         => $control_label,
                    'description'   => $control_description,
                    'section'       => 'sidemenu',
                    'settings'      => 'sidemenu_text_transform',
                    'type'          => 'select',
                    'choices'       => array(
                        '' => __('None', 'sidemenu'),
                        'capitalize' => __('Capitalise', 'sidemenu'),
                        'uppercase' => __('Uppercase', 'sidemenu'),
                        'lowercase' => __('Lowercase', 'sidemenu')
                    )
                ));

            } else {

                sidemenuCommon::add_hidden_control($wp_customize, 'sidemenu_text_transform', 'sidemenu', $label = $control_label, $control_description . ' ' . $upgrade_nag);

            }

            $control_label = __('SideMenu Text Font Size', 'sidemenu');
            $control_description = __('Change the font size of the text in the SideMenu.', 'sidemenu');

            if (sidemenuPremium::request_permission()) {

                $wp_customize->add_setting('sidemenu_text_font_size', array(
                    'default'       => '10',
                    'type'          => 'theme_mod',
                    'transport'     => 'postMessage',
                    'sanitize_callback' => 'absint'
                ));
                $wp_customize->add_control('sidemenu_text_font_size', array(
                    'label'         => $control_label,
                    'description'   => $control_description,
                    'section'       => 'sidemenu',
                    'settings'      => 'sidemenu_text_font_size',
                    'type'          => 'range',
                    'input_attrs' => array(
                        'min'   => 5,
                        'max'   => 20,
                        'step'  => 1
                    )
                ));

            } else {

                sidemenuCommon::add_hidden_control($wp_customize, 'sidemenu_text_font_size', 'sidemenu', $label = $control_label, $control_description . ' ' . $upgrade_nag);

            }

            $control_label = __('SideMenu Text Color', 'sidemenu');
            $control_description = __('Set the color of text in the SideMenu.', 'sidemenu');

            if (sidemenuPremium::request_permission()) {

                $wp_customize->add_setting('sidemenu_text_color', array(
                    'default'       => '#ffffff',
                    'type'          => 'theme_mod',
                    'transport'     => 'postMessage',
                    'sanitize_callback' => 'sanitize_hex_color'
                ));
                $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'sidemenu_text_color', array(
                    'label'         => $control_label,
                    'description'   => $control_description,
                    'section'       => 'sidemenu',
                	'settings'      => 'sidemenu_text_color'
                )));

            } else {

                sidemenuCommon::add_hidden_control($wp_customize, 'sidemenu_text_color', 'sidemenu', $label = $control_label, $control_description . ' ' . $upgrade_nag);

            }

            $control_label = __('SideMenu Link Color', 'sidemenu');
            $control_description = __('Set the color of links in the SideMenu.', 'sidemenu');

            if (sidemenuPremium::request_permission()) {

                $wp_customize->add_setting('sidemenu_link_color', array(
                    'default'       => '#d3d3d3',
                    'type'          => 'theme_mod',
                    'transport'     => 'postMessage',
                    'sanitize_callback' => 'sanitize_hex_color'
                ));
                $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'sidemenu_link_color', array(
                    'label'         => $control_label,
                    'description'   => $control_description,
                    'section'       => 'sidemenu',
                	'settings'      => 'sidemenu_link_color'
                )));

            } else {

                sidemenuCommon::add_hidden_control($wp_customize, 'sidemenu_link_color', 'sidemenu', $label = $control_label, $control_description . ' ' . $upgrade_nag);

            }

            $control_label = __('SideMenu Link Hover Color', 'sidemenu');
            $control_description = __('Set the color of hovered links in the SideMenu.', 'sidemenu');

            if (sidemenuPremium::request_permission()) {

                $wp_customize->add_setting('sidemenu_link_hover_color', array(
                    'default'       => '#000000',
                    'type'          => 'theme_mod',
                    'transport'     => 'refresh',
                    'sanitize_callback' => 'sanitize_hex_color'
                ));
                $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'sidemenu_link_hover_color', array(
                    'label'         => $control_label,
                    'description'   => $control_description,
                    'section'       => 'sidemenu',
                	'settings'      => 'sidemenu_link_hover_color'
                )));

            } else {

                sidemenuCommon::add_hidden_control($wp_customize, 'sidemenu_link_hover_color', 'sidemenu', $label = $control_label, $control_description . ' ' . $upgrade_nag);

            }

            $control_label = __('Section Border Width', 'sidemenu');
            $control_description = __('Set the width of the border inbetween sections in the SideMenu.', 'sidemenu');

            if (sidemenuPremium::request_permission()) {

                $wp_customize->add_setting('sidemenu_section_border_width', array(
                    'default'       => '2',
                    'type'          => 'theme_mod',
                    'transport'     => 'refresh',
                    'sanitize_callback' => 'absint'
                ));
                $wp_customize->add_control('sidemenu_section_border_width', array(
                    'label'         => $control_label,
                    'description'   => $control_description,
                    'section'       => 'sidemenu',
                    'settings'      => 'sidemenu_section_border_width',
                    'type'          => 'range',
                    'input_attrs' => array(
                        'min'   => 1,
                        'max'   => 11,
                        'step'  => 1
                    )
                ));

            } else {

                sidemenuCommon::add_hidden_control($wp_customize, 'sidemenu_section_border_width', 'sidemenu', $label = $control_label, $control_description . ' ' . $upgrade_nag);

            }

            $control_label = __('Section Border Color', 'sidemenu');
            $control_description = __('Set the color of the border inbetween sections in the SideMenu.', 'sidemenu');

            if (sidemenuPremium::request_permission()) {

                $wp_customize->add_setting('sidemenu_section_border_color', array(
                    'default'       => '',
                    'type'          => 'theme_mod',
                    'transport'     => 'refresh',
                    'sanitize_callback' => 'sanitize_hex_color'
                ));
                $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'sidemenu_section_border_color', array(
                    'label'         => $control_label,
                    'description'   => $control_description,
                    'section'       => 'sidemenu',
                	'settings'      => 'sidemenu_section_border_color'
                )));

            } else {

                sidemenuCommon::add_hidden_control($wp_customize, 'sidemenu_section_border_color', 'sidemenu', $label = $control_label, $control_description . ' ' . $upgrade_nag);

            }

            $control_label = __('Section Border Style', 'sidemenu');
            $control_description = __('Set the style of the border inbetween sections in the SideMenu.', 'sidemenu');

            if (sidemenuPremium::request_permission()) {

                $wp_customize->add_setting('sidemenu_section_border_style', array(
                    'default'       => '',
                    'type'          => 'theme_mod',
                    'transport'     => 'refresh',
                    'sanitize_callback' => 'sidemenuCommon::sanitize_options'
                ));
                $wp_customize->add_control('sidemenu_section_border_style', array(
                    'label'         => $control_label,
                    'description'   => $control_description,
                    'section'       => 'sidemenu',
                    'settings'      => 'sidemenu_section_border_style',
                    'type'          => 'select',
                    'choices'       => array(
                        'dotted' => __('Dotted', 'sidemenu'),
                        'dashed' => __('Dashed', 'sidemenu'),
                        '' => __('Solid', 'sidemenu'),
                        'double' => __('Double', 'sidemenu'),
                        'groove' => __('3D Groove', 'sidemenu'),
                        'ridge' => __('3D Ridge', 'sidemenu'),
                        'inset' => __('3D Inset', 'sidemenu'),
                        'outset' => __('3D Outset', 'sidemenu')
                    )
                ));

            } else {

                sidemenuCommon::add_hidden_control($wp_customize, 'sidemenu_section_border_style', 'sidemenu', $label = $control_label, $control_description . ' ' . $upgrade_nag);

            }

        }

        function sidemenu_header_output() {

?>
<!--Customizer CSS-->
<style type="text/css">
<?php

if (sidemenuPremium::request_permission()) {

            $mod = absint(get_theme_mod('sidemenu_overlay_opacity'));

            if ($mod) {

                $mod = ($mod - 1) / 10;

?>
.sidemenu_open>.cover {
    opacity: <?= $mod; ?>;
}
<?php

            }

            $sidemenu_width = get_theme_mod('sidemenu_width');

            if (absint($sidemenu_width)) {

                if (get_theme_mod('sidemenu_position')) {

?>
@media screen and (min-width: 48em) {
    .sidemenu {
        left: -<?= absint($sidemenu_width); ?>%;
        width: <?= absint($sidemenu_width); ?>%;
    }
}
.sidemenu_open>div {
    transform: translateX(<?= absint($sidemenu_width / 2); ?>%);
}
<?php

                } else {

?>
@media screen and (min-width: 48em) {
    .sidemenu {
        right: -<?= absint($sidemenu_width); ?>%;
        width: <?= absint($sidemenu_width); ?>%;
    }
}
.sidemenu_open>div {
    transform: translateX(-<?= absint($sidemenu_width / 2); ?>%);
}
<?php

                }

            }

            $mod = get_theme_mod('sidemenu_min_width');

            if (absint($mod)) {

?>
@media screen and (min-width: 48em) {
    .sidemenu {
        min-width: <?= absint($mod); ?>px;
    }
}
<?php

                if (!absint($sidemenu_width)) {

                    $sidemenu_width = 45;

                }

?>
@media screen and (min-width: 48em) and (max-width: <?= ceil((100 * absint($mod)) / absint($sidemenu_width)); ?>px) {
    .sidemenu {
<?php

                if (get_theme_mod('sidemenu_position')) {

?>
        left: -<?= absint($mod); ?>px;
<?php

                } else {

?>
        right: -<?= absint($mod); ?>px;
<?php

                }

?>
    }
}
<?php

            }

            $mod = get_theme_mod('sidemenu_height');

            if (absint($mod)) {

?>
@media screen and (min-width: 48em) {
    .sidemenu {
        top: <?= (100 - absint($mod)) / 2; ?>%;
        bottom: <?= (100 - absint($mod)) / 2; ?>%;
    }
}
<?php

            }

            sidemenuCommon::generate_css('.sidemenu_open>div', 'transform', 'sidemenu_no_content_animation', '', '', 'none');
            sidemenuCommon::generate_css('.open_sidemenu .dashicons', 'width', 'sidemenu_dashicon_size', '', 'px');
            sidemenuCommon::generate_css('.open_sidemenu .dashicons', 'height', 'sidemenu_dashicon_size', '', 'px');
            sidemenuCommon::generate_css('.open_sidemenu .dashicons', 'font-size', 'sidemenu_dashicon_size', '', 'px');
            sidemenuCommon::generate_css('body>.cover', 'background-color', 'sidemenu_overlay_color');
            sidemenuCommon::generate_css('.sidemenu', 'background-color', 'sidemenu_background_color');
            sidemenuCommon::generate_css('.sidemenu section h2', 'text-align', 'sidemenu_title_text_align');
            sidemenuCommon::generate_css('.sidemenu section h2', 'text-transform', 'sidemenu_title_text_transform');
            sidemenuCommon::generate_css('.sidemenu section h2', 'font-size', 'sidemenu_title_font_size', '', 'em', (get_theme_mod('sidemenu_title_font_size') ? (absint(get_theme_mod('sidemenu_title_font_size')) / 10) : ''));
            sidemenuCommon::generate_css('.sidemenu section h2', 'font-weight', 'sidemenu_title_font_weight');
            sidemenuCommon::generate_css('.sidemenu section h2', 'color', 'sidemenu_title_color');

            $mod = absint(get_theme_mod('sidemenu_menu_padding'));

            if ($mod) {

?>
.sidemenu .widget li, .sidemenu .menu li {
padding-top: <?= $mod / 10; ?>em;
padding-bottom: <?= $mod / 10; ?>em;
}
<?php

            }

            sidemenuCommon::generate_css('.sidemenu p, .sidemenu li', 'text-align', 'sidemenu_text_align');
            sidemenuCommon::generate_css('.sidemenu p, .sidemenu li', 'text-transform', 'sidemenu_text_transform');
            sidemenuCommon::generate_css('.sidemenu p, .sidemenu li', 'font-size', 'sidemenu_text_font_size', '', 'em', (get_theme_mod('sidemenu_text_font_size') ? (absint(get_theme_mod('sidemenu_text_font_size')) / 10) : ''));
            sidemenuCommon::generate_css('.sidemenu', 'color', 'sidemenu_text_color');
            sidemenuCommon::generate_css('.sidemenu section a', 'color', 'sidemenu_link_color');
            sidemenuCommon::generate_css('.sidemenu section a:hover, .sidemenu section ul li a:hover', 'color', 'sidemenu_link_hover_color');
            sidemenuCommon::generate_css('.sidemenu section', 'border-bottom-width', 'sidemenu_section_border_width', '', 'px', (get_theme_mod('sidemenu_section_border_width') ? (absint(get_theme_mod('sidemenu_section_border_width')) - 1) : ''));
            sidemenuCommon::generate_css('.sidemenu section', 'border-bottom-color', 'sidemenu_section_border_color');
            sidemenuCommon::generate_css('.sidemenu section', 'border-bottom-style', 'sidemenu_section_border_style');

}

?>
</style> 
<!--/Customizer CSS-->
<?php

        }

        function sidemenu_enqueue_customize_preview_js() {

            wp_enqueue_script('sidemenu-premium-customize-preview', plugin_dir_url(__FILE__) . 'js/customize-preview.js', array('jquery', 'customize-preview'), sidemenuPremium::plugin_version(), true);

        }

        function sidemenu_theme_options_metabox_setup() {

            add_action('add_meta_boxes', array($this, 'sidemenu_add_theme_options_metabox'));

            if (sidemenuPremium::request_permission()) {

                add_action('save_post', array($this, 'sidemenu_save_theme_options_meta'), 10, 2);

            }

        }

        function sidemenu_add_theme_options_metabox() {

            add_meta_box('sidemenu_meta_box', __('SideMenu', 'sidemenu'), array($this, 'sidemenu_render_theme_options_metabox'), array('post', 'page'), 'side');

        }

        function sidemenu_render_theme_options_metabox($post) {

            $upgrade_link = '<a href="' . sidemenuCommon::upgrade_link() . '" title="' . __('Upgrade SideMenu', 'sidemenu') . '">' . __('Upgrade SideMenu', 'sidemenu') . '</a>';

            if (get_option('sidemenu_purchased') == false) {

                if (get_option('sidemenu_trial_date') && time() < (strtotime('+1 week', get_option('sidemenu_trial_date')))) {

                    $expiring_in = ceil(abs((strtotime('+1 week', get_option('sidemenu_trial_date'))) - time())/60/60/24);
                    $expiring_text = '<p><span class="attention">' . sprintf(_n('SideMenu Premium plugin trial expires in less than %s day!', 'SideMenu Premium plugin trial expires in less than %s days!', $expiring_in, 'sidemenu'), $expiring_in) . '</span>';
                    echo('<strong>' . $expiring_text . '</strong>' . ' ' . $upgrade_link . ' ' . __('to keep using all the options after that time.', 'sidemenu') . '</p>');

                }

            }

            wp_nonce_field('sidemenu', 'sidemenu-meta-nonce');

            if (sidemenuPremium::request_permission()) {

                $auto_open_args = get_theme_mod('sidemenu_auto_open');
                $auto_open = false;

                if (is_array($auto_open_args) && (
                    in_array('all', $auto_open_args) ||
                    (in_array('front_page', $auto_open_args) && get_option('page_on_front') == $post->ID) ||
                    (in_array('home', $auto_open_args) && get_option('page_for_posts') == $post->ID) ||
                    (in_array('single', $auto_open_args) && $post->post_type == 'page') ||
                    (in_array('post_type/' . $post->post_type, $auto_open_args))
                )) {

                    $auto_open = true;

                }

?>
<input type="checkbox" name="sidemenu-auto-open" id="sidemenu-auto-open" value="1" <?php checked(get_post_meta($post->ID, 'sidemenu_auto_open', true), '1' ); ?> />
<label for="sidemenu-auto-open"><?= $auto_open ? __('Do not auto-open SideMenu', 'sidemenu') : __('Auto-open SideMenu', 'sidemenu'); ?></label><?php

            } else {

?>

<p><?= $upgrade_link; ?> <?= __('to choose where to auto-open the sidemenu.', 'sidemenu'); ?></p>

<?php
            }

        }

        function sidemenu_save_theme_options_meta($post_id, $post) {

            if (!isset($_POST['sidemenu-meta-nonce']) || !wp_verify_nonce($_POST['sidemenu-meta-nonce'], 'sidemenu')) {

                return;

            }

            $post_type = get_post_type_object($post->post_type);

            if (!current_user_can($post_type->cap->edit_post, $post_id)) {

                return;

            }

            if (isset($_POST['sidemenu-auto-open']) && $_POST['sidemenu-auto-open'] == '1') {

                update_post_meta($post_id, 'sidemenu_auto_open', 1);

            } else {

                delete_post_meta($post_id, 'sidemenu_auto_open');

            }

        }

        function sidemenu_enqueue_scripts() {

            $auto_open_args = get_theme_mod('sidemenu_auto_open');

            if (!is_admin() && is_array($auto_open_args)) {

                if (is_page() || is_single()) { 

                    global $post;

                }

                if (is_archive()) {

                    global $wp_query;
                    $taxonomy = $wp_query->get_queried_object();

                }

                $auto_open = false;

                if (
                    in_array('all', $auto_open_args) ||
                    (in_array('front_page', $auto_open_args) && is_front_page()) ||
                    (in_array('home', $auto_open_args) && is_home()) ||
                    (in_array('single', $auto_open_args) && is_single()) ||
                    (in_array('archive', $auto_open_args) && is_archive()) ||
                    (is_single() && in_array('post_type/' . get_post_type() , $auto_open_args)) ||
                    (is_page() && in_array('post_type/page', $auto_open_args)) ||
                    (is_archive() && isset($taxonomy->taxonomy) && in_array('taxonomy/' . get_post_type() . '/' . $taxonomy->taxonomy, $auto_open_args))
                ) {

                    $auto_open = true;

                }

                if (((is_single() || is_page()) && get_post_meta($post->ID, 'sidemenu_auto_open', true) == '1')) {

                    $auto_open = !$auto_open;

                }

                if ($auto_open) {

                		wp_enqueue_script('sidemenu-premium-js', plugin_dir_url(__FILE__) . 'js/sidemenu-premium.js', array(), sidemenuPremium::plugin_version(), true);

                        $l10n = array();
                        $l10n['autoopen'] = true;
                        $l10n['autoopendelay'] = get_theme_mod('sidemenu_auto_open_delay');

                        wp_localize_script(
                            'sidemenu-premium-js',
                            'sideMenuPremium',
                            $l10n
                        );

                }

            }

        }

	}

    if (!class_exists('sidemenuPremium')) {

        require_once(dirname(__FILE__) . '/includes/class-sidemenu-premium.php');

    }

    function sidemenu_premium_init() {

        if (class_exists('sidemenu_class') && class_exists('sidemenuCommon')) {

            sidemenuPremium::start_trial();
            $sidemenu_premium_object = new sidemenu_premium_class();

        } else {

            add_action('admin_notices', 'sidemenuPremium::free_plugin_notice');

        }

    }

    add_action('plugins_loaded', 'sidemenu_premium_init');

}

?>
